%define		crates_ver	0.8.3

Summary:	A viewer for git and diff output
Name:		delta
Version:	0.8.3
Release:	2
License:	MIT
Group:		Applications
Source0:	https://github.com/dandavison/delta/archive/%{version}/%{name}-%{version}.tar.gz
# Source0-md5:	2d5b4c862b8231a826ac016d505c7bb5
# ./create-crates.sh
Source1:	%{name}-crates-%{crates_ver}.tar.xz
# Source1-md5:	f2fcdc51f618201bbd02eefa6bb57a19
URL:		https://github.com/dandavison/delta
BuildRequires:	cargo
BuildRequires:	libgit2-devel >= 1.1.0
BuildRequires:	oniguruma-devel >= 6.9.3
BuildRequires:	pkgconfig
BuildRequires:	rpmbuild(macros) >= 2.004
BuildRequires:	rust
BuildRequires:	tar >= 1:1.22
BuildRequires:	xz
Requires:	libgit2 >= 1.1.0
Requires:	oniguruma >= 6.9.3
ExclusiveArch:	%{rust_arches}
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
Delta aims to make studying diffs both efficient and enjoyable: it
allows you to make extensive changes to the layout and styling of
diffs, as well as allowing you to stay arbitrarily close to the
default git/diff output, changing just the aspects that you want to
change.

Delta's main features are:

- Language syntax highlighting with color themes
- Within-line highlights based on a Levenshtein edit inference
  algorithm
- Style (foreground color, background color, font attributes) can be
  configured independently for more than 20 different sections of the
  diff
- Stylable box/line decorations to draw attention to commit, file and
  hunk header sections.
- Line numbering (`-n`)
- `--diff-highlight` and `--diff-so-fancy` emulation modes
- Code can be copied directly from the diff (`-/+` markers are removed
  by default).
- `n` and `N` keybindings to move between files in large diffs, and
  between diffs in `log -p` views (`--navigate`) A viewer for git and
  diff output.

%prep
%setup -q -a1

%{__mv} delta-%{crates_ver}/* .
sed -i -e 's/@@VERSION@@/%{version}/' Cargo.lock

# use our offline registry
export CARGO_HOME="$(pwd)/.cargo"

mkdir -p "$CARGO_HOME"
cat >.cargo/config <<EOF
[source.crates-io]
registry = 'https://github.com/rust-lang/crates.io-index'
replace-with = 'vendored-sources'

[source.vendored-sources]
directory = '$PWD/vendor'
EOF

%build
export CARGO_HOME="$(pwd)/.cargo"
export RUSTONIG_SYSTEM_LIBONIG=true

%cargo_build --frozen

%install
rm -rf $RPM_BUILD_ROOT
export CARGO_HOME="$(pwd)/.cargo"

%cargo_install --frozen --root $RPM_BUILD_ROOT%{_prefix} --path $PWD
%{__rm} $RPM_BUILD_ROOT%{_prefix}/.crates*

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(644,root,root,755)
%doc README.md
%attr(755,root,root) %{_bindir}/delta
%changelog
* Sun Sep 05 2021 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/delta.git;a=log;h=master

* Sun Sep 05 2021 Jan Rękorajski <baggins@pld-linux.org> 24dc4ee
- Release 2 (by relup.sh)

* Tue Jul 13 2021 Jan Palus <atler@pld-linux.org> 9e45a6d
- up to 0.8.3

* Tue Jun 29 2021 Jan Palus <atler@pld-linux.org> 52f29b2
- link against system oniguruma

* Tue Jun 29 2021 Jan Palus <atler@pld-linux.org> a0e607b
- up to 0.8.2

* Fri Jun 25 2021 Jan Palus <atler@pld-linux.org> f786197
- up to 0.8.1

* Fri May 28 2021 Jan Palus <atler@pld-linux.org> e38c63a
- updated deps

* Fri May 28 2021 Jan Palus <atler@pld-linux.org> 2cf61d6
- up to 0.8.0

* Wed Mar 31 2021 Jan Palus <atler@pld-linux.org> 2031486
- proper rebuild on x32; rel 3

* Wed Mar 31 2021 Jan Palus <atler@pld-linux.org> a311b6b
- add EA

* Tue Mar 30 2021 Jan Palus <atler@pld-linux.org> e5a4ca8
- use cargo macros to automatically handle debuginfo; rel 2

* Tue Mar 30 2021 Jan Palus <atler@pld-linux.org> d037b48
- up to 0.7.1

* Fri Feb 05 2021 Jan Palus <atler@pld-linux.org> c42db62
- BRs for tar.xz source

* Fri Feb 05 2021 Jan Palus <atler@pld-linux.org> 3837b13
- up to 0.6.0

* Fri Feb 05 2021 Jan Palus <atler@pld-linux.org> 4a2626b
- add support for reusing crates from older package version

* Fri Feb 05 2021 Jan Palus <atler@pld-linux.org> f2b5808
- added script for creating crates tarball

* Fri Jan 01 2021 Jan Palus <atler@pld-linux.org> 0e37833
- up to 0.5.0

* Wed Dec 23 2020 Jan Palus <atler@pld-linux.org> 6b1be06
- up to 0.4.5

* Sun Oct 11 2020 Jan Palus <atler@pld-linux.org> 0981711
- up to 0.4.4

* Fri Sep 04 2020 Jan Palus <atler@pld-linux.org> d49c59f
- up to 0.4.3

* Mon Aug 10 2020 Jan Palus <atler@pld-linux.org> 80f5ed9
- up to 0.4.1

